@@ -20,6 +20,7 @@
 
 extern Client_Charset utf8;
 extern MARIADB_CHARSET_INFO*  utf16;
+Client_Charset SourceAnsiCs= {0, 0}; /* Basically it should be initialized with 0 anyway */
 
 MARIADB_CHARSET_INFO * mysql_find_charset_name(const char *name);
 
@@ -54,6 +55,7 @@ SQLRETURN MADB_EnvFree(MADB_Env *Env)
 /* }}} */
 
 const char* GetDefaultLogDir();
+int         GetSourceAnsiCs(Client_Charset *cc);
 
 /* {{{ MADB_EnvInit */
 MADB_Env *MADB_EnvInit()
@@ -103,6 +105,7 @@ MADB_Env *MADB_EnvInit()
   }
   utf8.cs_info= mariadb_get_charset_by_name("utf8");
   GetDefaultLogDir();
+  GetSourceAnsiCs(&SourceAnsiCs);
 
 cleanup:
 #ifdef _WIN32  
